@@ -89,6 +89,8 @@ public class StartParameter implements LoggingConfiguration, Serializable {
     private int maxWorkerCount;
     private boolean continuous;
     private List<File> includedBuilds = new ArrayList<File>();
+    private boolean buildScan;
+    private boolean noBuildScan;
 
     /**
      * {@inheritDoc}
@@ -773,4 +775,44 @@ public class StartParameter implements LoggingConfiguration, Serializable {
         return Collections.unmodifiableList(includedBuilds);
     }
 
+    /**
+     * Returns true if build scan should be created.
+     *
+     * @since 3.4
+     */
+    @Incubating
+    public boolean isBuildScan() {
+        return buildScan;
+    }
+
+    /**
+     * Specifies whether a build scan should be created.
+     *
+     * @since 3.4
+     */
+    @Incubating
+    public void setBuildScan(boolean buildScan) {
+        this.buildScan = buildScan;
+    }
+
+    /**
+     * Returns true when build scan creation is explicitly disabled.
+     *
+     * @since 3.4
+     */
+    @Incubating
+    public boolean isNoBuildScan() {
+        return noBuildScan;
+    }
+
+    /**
+     * Specifies whether build scan creation is explicitly disabled.
+     *
+     * @since 3.4
+     */
+    @Incubating
+    public void setNoBuildScan(boolean noBuildScan) {
+        this.noBuildScan = noBuildScan;
+    }
+
 }
