@@ -15,7 +15,9 @@
  */
 package org.gradle.api.internal.artifacts.ivyservice.modulecache;
 
+import com.google.common.base.Objects;
 import org.gradle.api.artifacts.component.ModuleComponentIdentifier;
+import org.gradle.api.internal.artifacts.ivyservice.ArtifactCacheMetaData;
 import org.gradle.api.internal.artifacts.ivyservice.CacheLockingManager;
 import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.ModuleComponentRepository;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.result.ComponentIdentifierSerializer;
@@ -25,9 +27,9 @@ import org.gradle.internal.component.external.model.MutableModuleComponentResolv
 import org.gradle.internal.hash.HashValue;
 import org.gradle.internal.resource.local.LocallyAvailableResource;
 import org.gradle.internal.resource.local.PathKeyFileStore;
+import org.gradle.internal.serialize.AbstractSerializer;
 import org.gradle.internal.serialize.Decoder;
 import org.gradle.internal.serialize.Encoder;
-import org.gradle.internal.serialize.Serializer;
 import org.gradle.util.BuildCommencedTimeProvider;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -39,37 +41,39 @@ public class DefaultModuleMetaDataCache implements ModuleMetaDataCache {
     private final CacheLockingManager cacheLockingManager;
 
     private final ModuleMetadataStore moduleMetadataStore;
-    private PersistentIndexedCache<RevisionKey, ModuleMetadataCacheEntry> cache;
+    private PersistentIndexedCache<ModuleComponentAtRepositoryKey, ModuleMetadataCacheEntry> cache;
 
-    public DefaultModuleMetaDataCache(BuildCommencedTimeProvider timeProvider, CacheLockingManager cacheLockingManager) {
+    public DefaultModuleMetaDataCache(BuildCommencedTimeProvider timeProvider, CacheLockingManager cacheLockingManager, ArtifactCacheMetaData artifactCacheMetaData) {
         this.timeProvider = timeProvider;
         this.cacheLockingManager = cacheLockingManager;
 
-        moduleMetadataStore = new ModuleMetadataStore(new PathKeyFileStore(cacheLockingManager.createMetaDataStore()), new ModuleMetadataSerializer());
+        moduleMetadataStore = new ModuleMetadataStore(new PathKeyFileStore(artifactCacheMetaData.getMetaDataStoreDirectory()), new ModuleMetadataSerializer());
     }
 
-    private PersistentIndexedCache<RevisionKey, ModuleMetadataCacheEntry> getCache() {
+    private PersistentIndexedCache<ModuleComponentAtRepositoryKey, ModuleMetadataCacheEntry> getCache() {
         if (cache == null) {
             cache = initCache();
         }
         return cache;
     }
 
-    private PersistentIndexedCache<RevisionKey, ModuleMetadataCacheEntry> initCache() {
+    private PersistentIndexedCache<ModuleComponentAtRepositoryKey, ModuleMetadataCacheEntry> initCache() {
         return cacheLockingManager.createCache("module-metadata", new RevisionKeySerializer(), new ModuleMetadataCacheEntrySerializer());
     }
 
     public CachedMetaData getCachedModuleDescriptor(ModuleComponentRepository repository, ModuleComponentIdentifier componentId) {
-        ModuleMetadataCacheEntry entry = getCache().get(createKey(repository, componentId));
+        ModuleComponentAtRepositoryKey key = createKey(repository, componentId);
+        ModuleMetadataCacheEntry entry = getCache().get(key);
         if (entry == null) {
             return null;
         }
         if (entry.isMissing()) {
             return new DefaultCachedMetaData(entry, null, timeProvider);
         }
-        MutableModuleComponentResolveMetadata metadata = moduleMetadataStore.getModuleDescriptor(repository, componentId);
+        MutableModuleComponentResolveMetadata metadata = moduleMetadataStore.getModuleDescriptor(key);
         if (metadata == null) {
             // Descriptor file has been deleted - ignore the entry
+            getCache().remove(key);
             return null;
         }
         return new DefaultCachedMetaData(entry, entry.configure(metadata), timeProvider);
@@ -84,61 +88,48 @@ public class DefaultModuleMetaDataCache implements ModuleMetaDataCache {
 
     public CachedMetaData cacheMetaData(ModuleComponentRepository repository, ModuleComponentResolveMetadata metadata) {
         LOGGER.debug("Recording module descriptor in cache: {} [changing = {}]", metadata.getComponentId(), metadata.isChanging());
-        LocallyAvailableResource resource = moduleMetadataStore.putModuleDescriptor(repository, metadata);
+        ModuleComponentAtRepositoryKey key = createKey(repository, metadata.getComponentId());
+        LocallyAvailableResource resource = moduleMetadataStore.putModuleDescriptor(key, metadata);
         ModuleMetadataCacheEntry entry = createEntry(metadata, resource.getSha1());
-        getCache().put(createKey(repository, metadata.getComponentId()), entry);
+        getCache().put(key, entry);
         return new DefaultCachedMetaData(entry, null, timeProvider);
     }
 
-    private RevisionKey createKey(ModuleComponentRepository repository, ModuleComponentIdentifier id) {
-        return new RevisionKey(repository.getId(), id);
+    private ModuleComponentAtRepositoryKey createKey(ModuleComponentRepository repository, ModuleComponentIdentifier id) {
+        return new ModuleComponentAtRepositoryKey(repository.getId(), id);
     }
 
     private ModuleMetadataCacheEntry createEntry(ModuleComponentResolveMetadata metaData, HashValue moduleDescriptorHash) {
         return ModuleMetadataCacheEntry.forMetaData(metaData, timeProvider.getCurrentTime(), moduleDescriptorHash.asBigInteger());
     }
 
-    private static class RevisionKey {
-        private final String repositoryId;
-        private final ModuleComponentIdentifier componentId;
+    private static class RevisionKeySerializer extends AbstractSerializer<ModuleComponentAtRepositoryKey> {
+        private final ComponentIdentifierSerializer componentIdSerializer = new ComponentIdentifierSerializer();
 
-        private RevisionKey(String repositoryId, ModuleComponentIdentifier componentId) {
-            this.repositoryId = repositoryId;
-            this.componentId = componentId;
+        public void write(Encoder encoder, ModuleComponentAtRepositoryKey value) throws Exception {
+            encoder.writeString(value.getRepositoryId());
+            componentIdSerializer.write(encoder, value.getComponentId());
+        }
+
+        public ModuleComponentAtRepositoryKey read(Decoder decoder) throws Exception {
+            String resolverId = decoder.readString();
+            ModuleComponentIdentifier identifier = (ModuleComponentIdentifier) componentIdSerializer.read(decoder);
+            return new ModuleComponentAtRepositoryKey(resolverId, identifier);
         }
 
         @Override
-        public String toString() {
-            return repositoryId + "," + componentId;
-        }
-
-        @Override
-        public boolean equals(Object o) {
-            if (o == null || !(o instanceof RevisionKey)) {
+        public boolean equals(Object obj) {
+            if (!super.equals(obj)) {
                 return false;
             }
-            RevisionKey other = (RevisionKey) o;
-            return repositoryId.equals(other.repositoryId) && componentId.equals(other.componentId);
+
+            RevisionKeySerializer rhs = (RevisionKeySerializer) obj;
+            return Objects.equal(componentIdSerializer, rhs.componentIdSerializer);
         }
 
         @Override
         public int hashCode() {
-            return repositoryId.hashCode() ^ componentId.hashCode();
-        }
-    }
-
-    private static class RevisionKeySerializer implements Serializer<RevisionKey> {
-        private final ComponentIdentifierSerializer componentIdSerializer = new ComponentIdentifierSerializer();
-
-        public void write(Encoder encoder, RevisionKey value) throws Exception {
-            encoder.writeString(value.repositoryId);
-            componentIdSerializer.write(encoder, value.componentId);
-        }
-
-        public RevisionKey read(Decoder decoder) throws Exception {
-            String resolverId = decoder.readString();
-            ModuleComponentIdentifier identifier = (ModuleComponentIdentifier) componentIdSerializer.read(decoder);
-            return new RevisionKey(resolverId, identifier);
+            return Objects.hashCode(super.hashCode(), componentIdSerializer);
         }
     }
 }
