@@ -16,10 +16,10 @@
 
 package org.gradle.api.internal.artifacts.ivyservice.resolutionstrategy;
 
-import org.gradle.api.artifacts.ConflictResolution;
+import org.gradle.api.internal.artifacts.configurations.ConflictResolution;
 
 /**
  * Strict type, allows configuring (forcing) certain dependency versions using dependency notation
  */
 public class StrictConflictResolution implements ConflictResolution {
-}
\ No newline at end of file
+}
