@@ -32,8 +32,10 @@ import org.gradle.api.internal.artifacts.configurations.OutgoingVariant;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.excludes.ModuleExclusion;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.excludes.ModuleExclusions;
 import org.gradle.api.internal.attributes.AttributeContainerInternal;
+import org.gradle.api.internal.attributes.ImmutableAttributes;
 import org.gradle.internal.component.model.ComponentArtifactMetadata;
 import org.gradle.internal.component.model.ComponentResolveMetadata;
+import org.gradle.internal.component.model.ConfigurationMetadata;
 import org.gradle.internal.component.model.DefaultVariantMetadata;
 import org.gradle.internal.component.model.Exclude;
 import org.gradle.internal.component.model.IvyArtifactName;
@@ -56,6 +58,7 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
     private final ComponentIdentifier componentIdentifier;
     private final String status;
     private final AttributesSchema attributesSchema;
+    private List<ConfigurationMetadata> consumableConfigurations;
 
     public DefaultLocalComponentMetadata(ModuleVersionIdentifier id, ComponentIdentifier componentIdentifier, String status, AttributesSchema attributesSchema) {
         this.id = id;
@@ -172,6 +175,19 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
         return allConfigurations.keySet();
     }
 
+    @Override
+    public List<? extends ConfigurationMetadata> getConsumableConfigurationsHavingAttributes() {
+        if (consumableConfigurations == null) {
+            consumableConfigurations = Lists.newArrayListWithExpectedSize(allConfigurations.size());
+            for (DefaultLocalConfigurationMetadata metadata : allConfigurations.values()) {
+                if (metadata.isCanBeConsumed() && !metadata.getAttributes().isEmpty()) {
+                    consumableConfigurations.add(metadata);
+                }
+            }
+        }
+        return consumableConfigurations;
+    }
+
     @Override
     public LocalConfigurationMetadata getConfiguration(final String name) {
         return allConfigurations.get(name);
@@ -266,7 +282,7 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
         public Set<? extends VariantMetadata> getVariants() {
             Set<DefaultVariantMetadata> variants = allVariants.get(name);
             if (variants.isEmpty()) {
-                variants = ImmutableSet.of(new DefaultVariantMetadata(attributes, getArtifacts()));
+                variants = ImmutableSet.of(new DefaultVariantMetadata(ImmutableAttributes.EMPTY, getArtifacts()));
             }
             return variants;
         }
