@@ -16,12 +16,14 @@
 
 package org.gradle.internal.resource.cached.ivy;
 
+import com.google.common.base.Objects;
 import org.gradle.api.artifacts.component.ComponentArtifactIdentifier;
 import org.gradle.api.internal.artifacts.ivyservice.CacheLockingManager;
 import org.gradle.api.internal.artifacts.metadata.ComponentArtifactIdentifierSerializer;
 import org.gradle.internal.resource.cached.CachedArtifact;
 import org.gradle.internal.resource.cached.CachedArtifactIndex;
 import org.gradle.internal.resource.cached.DefaultCachedArtifact;
+import org.gradle.internal.serialize.AbstractSerializer;
 import org.gradle.internal.serialize.Decoder;
 import org.gradle.internal.serialize.Encoder;
 import org.gradle.internal.serialize.Serializer;
@@ -58,7 +60,7 @@ public class ArtifactAtRepositoryCachedArtifactIndex extends AbstractCachedIndex
         return new DefaultCachedArtifact(attemptedLocations, timeProvider.getCurrentTime(), descriptorHash);
     }
 
-    private static class ArtifactAtRepositoryKeySerializer implements Serializer<ArtifactAtRepositoryKey> {
+    private static class ArtifactAtRepositoryKeySerializer extends AbstractSerializer<ArtifactAtRepositoryKey> {
         private final Serializer<ComponentArtifactIdentifier> artifactIdSerializer = new ComponentArtifactIdentifierSerializer();
 
         public void write(Encoder encoder, ArtifactAtRepositoryKey value) throws Exception {
@@ -71,9 +73,24 @@ public class ArtifactAtRepositoryCachedArtifactIndex extends AbstractCachedIndex
             ComponentArtifactIdentifier artifactIdentifier = artifactIdSerializer.read(decoder);
             return new ArtifactAtRepositoryKey(repositoryId, artifactIdentifier);
         }
+
+        @Override
+        public boolean equals(Object obj) {
+            if (!super.equals(obj)) {
+                return false;
+            }
+
+            ArtifactAtRepositoryKeySerializer rhs = (ArtifactAtRepositoryKeySerializer) obj;
+            return Objects.equal(artifactIdSerializer, rhs.artifactIdSerializer);
+        }
+
+        @Override
+        public int hashCode() {
+            return Objects.hashCode(super.hashCode(), artifactIdSerializer);
+        }
     }
 
-    private static class CachedArtifactSerializer implements Serializer<CachedArtifact> {
+    private static class CachedArtifactSerializer extends AbstractSerializer<CachedArtifact> {
         public void write(Encoder encoder, CachedArtifact value) throws Exception {
             encoder.writeBoolean(value.isMissing());
             encoder.writeLong(value.getCachedAt());
