@@ -16,14 +16,18 @@
 
 package org.gradle.test.fixtures.file;
 
+import com.google.common.hash.Hashing;
+import com.google.common.io.Files;
 import groovy.lang.Closure;
 import groovy.lang.DelegatesTo;
 import org.apache.commons.io.FileUtils;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Zip;
 import org.codehaus.groovy.runtime.ResourceGroovyMethods;
+import org.gradle.api.UncheckedIOException;
 import org.gradle.internal.nativeintegration.filesystem.FileSystem;
 import org.gradle.internal.nativeintegration.services.NativeServices;
+import org.gradle.testing.internal.util.RetryUtil;
 import org.hamcrest.Matcher;
 
 import java.io.BufferedReader;
@@ -256,7 +260,7 @@ public class TestFile extends File {
                 FileUtils.copyDirectory(this, target);
             } catch (IOException e) {
                 throw new RuntimeException(String.format("Could not copy test directory '%s' to '%s'", this,
-                        target), e);
+                    target), e);
             }
         } else {
             try {
@@ -271,12 +275,18 @@ public class TestFile extends File {
         new TestFile(target).copyTo(this);
     }
 
-    public void copyFrom(URL resource) {
-        try {
-            FileUtils.copyURLToFile(resource, this);
-        } catch (IOException e) {
-            throw new RuntimeException(e);
-        }
+    public void copyFrom(final URL resource) {
+        final TestFile testFile = this;
+        RetryUtil.retry(new Closure(null, null) {
+            @SuppressWarnings("UnusedDeclaration")
+            void doCall() {
+                try {
+                    FileUtils.copyURLToFile(resource, testFile);
+                } catch (IOException e) {
+                    throw new UncheckedIOException(e);
+                }
+            }
+        });
     }
 
     public void moveToDirectory(File target) {
@@ -395,6 +405,14 @@ public class TestFile extends File {
         return this;
     }
 
+    public String getMd5Hash() {
+        try {
+            return Files.hash(this, Hashing.md5()).toString();
+        } catch (IOException e) {
+            throw new RuntimeException(e);
+        }
+    }
+
     private byte[] getHash(String algorithm) {
         try {
             MessageDigest messageDigest = MessageDigest.getInstance(algorithm);
@@ -518,7 +536,7 @@ public class TestFile extends File {
             return this;
         }
         throw new AssertionError("Problems creating dir: " + this
-                + ". Diagnostics: exists=" + this.exists() + ", isFile=" + this.isFile() + ", isDirectory=" + this.isDirectory());
+            + ". Diagnostics: exists=" + this.exists() + ", isFile=" + this.isFile() + ", isDirectory=" + this.isDirectory());
     }
 
     public TestFile createDir(Object path) {
@@ -532,6 +550,7 @@ public class TestFile extends File {
 
     /**
      * Attempts to delete this directory, ignoring failures to do so.
+     *
      * @return this
      */
     public TestFile maybeDeleteDir() {
