@@ -29,6 +29,8 @@ import org.gradle.internal.installation.GradleInstallation;
 import org.gradle.internal.io.StreamByteBuffer;
 import org.gradle.internal.serialize.FlushableEncoder;
 import org.gradle.internal.serialize.kryo.KryoBackedEncoder;
+import org.gradle.internal.time.Timer;
+import org.gradle.internal.time.Timers;
 import org.gradle.launcher.daemon.DaemonExecHandleBuilder;
 import org.gradle.launcher.daemon.bootstrap.DaemonGreeter;
 import org.gradle.launcher.daemon.bootstrap.DaemonOutputConsumer;
@@ -38,7 +40,6 @@ import org.gradle.launcher.daemon.diagnostics.DaemonStartupInfo;
 import org.gradle.launcher.daemon.registry.DaemonDir;
 import org.gradle.process.internal.ExecHandle;
 import org.gradle.process.internal.streams.EncodedStream;
-import org.gradle.util.Clock;
 import org.gradle.util.CollectionUtils;
 import org.gradle.util.GFileUtils;
 import org.gradle.util.GradleVersion;
@@ -136,7 +137,7 @@ public class DefaultDaemonStarter implements DaemonStarter {
 
     private DaemonStartupInfo startProcess(List<String> args, File workingDir, InputStream stdInput) {
         LOGGER.info("Starting daemon process: workingDir = {}, daemonArgs: {}", workingDir, args);
-        Clock clock = new Clock();
+        Timer clock = Timers.startTimer();
         try {
             GFileUtils.mkdirs(workingDir);
 
@@ -154,7 +155,7 @@ public class DefaultDaemonStarter implements DaemonStarter {
         } catch (Exception e) {
             throw new GradleException("Could not start Gradle daemon.", e);
         } finally {
-            LOGGER.info("An attempt to start the daemon took {}.", clock.getTime());
+            LOGGER.info("An attempt to start the daemon took {}.", clock.getElapsed());
         }
     }
 
